# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Azure


class _Migration(_Azure):
    _type = "migration"
    _icon_dir = "resources/azure/migration"


class DatabaseMigrationServices(_Migration):
    _icon = "database-migration-services.png"


class MigrationProjects(_Migration):
    _icon = "migration-projects.png"


class RecoveryServicesVaults(_Migration):
    _icon = "recovery-services-vaults.png"


# Aliases
