# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AWS


class _Iot(_AWS):
    _type = "iot"
    _icon_dir = "resources/aws/iot"


class Freertos(_Iot):
    _icon = "freertos.png"


class InternetOfThings(_Iot):
    _icon = "internet-of-things.png"


class Iot1Click(_Iot):
    _icon = "iot-1-click.png"


class IotAnalytics(_Iot):
    _icon = "iot-analytics.png"


class IotButton(_Iot):
    _icon = "iot-button.png"


class IotCore(_Iot):
    _icon = "iot-core.png"


class IotDeviceDefender(_Iot):
    _icon = "iot-device-defender.png"


class IotDeviceManagement(_Iot):
    _icon = "iot-device-management.png"


class IotEvents(_Iot):
    _icon = "iot-events.png"


class IotGreengrass(_Iot):
    _icon = "iot-greengrass.png"


class IotSitewise(_Iot):
    _icon = "iot-sitewise.png"


class IotThingsGraph(_Iot):
    _icon = "iot-things-graph.png"


# Aliases

FreeRTOS = Freertos
