# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _GCP


class _Iot(_GCP):
    _type = "iot"
    _icon_dir = "resources/gcp/iot"


class IotCore(_Iot):
    _icon = "iot-core.png"


# Aliases
