# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Azure


class _Mobile(_Azure):
    _type = "mobile"
    _icon_dir = "resources/azure/mobile"


class AppServiceMobile(_Mobile):
    _icon = "app-service---mobile.png"


class MobileEngagement(_Mobile):
    _icon = "mobile-engagement.png"


class NotificationHubs(_Mobile):
    _icon = "notification-hubs.png"


# Aliases
