# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _GCP


class _Storage(_GCP):
    _type = "storage"
    _icon_dir = "resources/gcp/storage"


class Filestore(_Storage):
    _icon = "filestore.png"


class PersistentDisk(_Storage):
    _icon = "persistent-disk.png"


class Storage(_Storage):
    _icon = "storage.png"


# Aliases

GCS = Storage
